@@ -4,7 +4,7 @@ use Time::HiRes qw/gettimeofday tv_interval/;
 use Net::Prometheus;
 use IPC::ShareLite;
 
-our $VERSION = '1.2.2';
+our $VERSION = '1.3.0';
 
 has prometheus => sub { Net::Prometheus->new(disable_process_collector => 1) };
 has route => sub {undef};
@@ -119,7 +119,8 @@ sub register {
   );
 
 
-  $self->route($app->routes->get($config->{path} // '/metrics'));
+  my $prefix = $config->{route} // $app->routes->under('/');
+  $self->route($prefix->get($config->{path} // '/metrics'));
   $self->route->to(
     cb => sub {
       my ($c) = @_;
